.side-panel {
    background: var(--app-layer-one);
    border-color: var(--app-primary);
    height: var(--app-side-panel-height);
    top: var(--app-top-navigation-height);
}

.btn-close-panel {
    align-items: center;
    background: transparent;
    border: none;
    border-radius: 50%;
    color: var(--app-primary);
    cursor: pointer;
    display: flex;
    height: 28px;
    justify-content: center;
    transition: background 0.2s ease, color 0.2s ease;
    width: 28px;
}

.btn-close-panel:hover {
    background: var(--app-primary);
    color: var(--app-default-button-text-color);
}

.panel-toggle-container {
    height: 30px;
    position: fixed;
    top: 50vh;
    transform: translateY(-50%);
    width: 30px;
}

.panel-toggle-container-left {
    left: 1.5rem;
}

.panel-toggle-container-right {
    right: 1.5rem;
}

.panel-toggle-container .btn {
    border-radius: 50% !important;
    height: 30px !important;
    line-height: 30px !important;
    min-width: 30px !important;
    padding: 0 !important;
    text-align: center !important;
    width: 30px !important;
}

.side-panel-transition-enter {
    transition: opacity 0.3s ease;
}

.side-panel-transition-enter-start-left,
.side-panel-transition-enter-start-right {
    opacity: 0;
}

.side-panel-transition-enter-end {
    opacity: 1;
}

.side-panel-transition-leave {
    transition: opacity 0.3s ease;
}

.side-panel-transition-leave-start {
    opacity: 1;
}

.side-panel-transition-leave-end-left,
.side-panel-transition-leave-end-right {
    opacity: 0;
}

@media (min-width: 992px) {
    .panel-toggle-container-left {
        left: var(--app-side-navigation-width);
    }
}

@media (max-width: 991px) {
    .mobile-hide {
        display: none !important;
    }

    .panel-toggle-container-left {
        left: 0.5rem;
    }

    .panel-toggle-container-right {
        right: 2rem;
    }

    .side-panel-left,
    .side-panel-right {
        border: none;
    }
}
