{% extends 'django_spire/theme/page/theme_page.html' %}

{% block theme_content %}
    {% include 'django_spire/theme/section/badge_section.html' %}
{% endblock %}

{% block theme_on_card_content %}
    {% include 'django_spire/theme/section/badge_section_card.html' %}
{% endblock %}

