{% extends 'django_spire/card/card.html' %}

{% block card_padding_class %}p-1{% endblock %}

{% block card_content %}
    {% include 'comment/element/comment_textarea_element.html' %}
{% endblock %}
