:root {
    --app-primary: #907aa9;
    --app-primary-soft: #f2e9e1;
    --app-primary-dark: #56526e;

    --app-secondary: #797593;
    --app-secondary-soft: #f2e9e1;
    --app-secondary-dark: #56526e;

    --app-accent: #d7827e;
    --app-accent-soft: #f4ede8;
    --app-accent-dark: #b4637a;

    --app-success: #286983;
    --app-success-soft: #e3f0f4;
    --app-success-dark: #1f5564;

    --app-warning: #ea9d34;
    --app-warning-soft: #fef6e7;
    --app-warning-dark: #b77c25;

    --app-danger: #d7827e;
    --app-danger-soft: #f4ede8;
    --app-danger-dark: #b4637a;

    --app-layer-one: #fffaf3;
    --app-layer-two: #f2e9e1;
    --app-layer-three: #e6ddd6;
    --app-layer-four: #cecacd;

    --app-alt-layer-one: #fdf8f2;
    --app-alt-layer-two: #f5ebe3;
    --app-alt-layer-three: #e9dfd8;
    --app-alt-layer-four: #d6d2d5;

    --app-card-header: #e6ddd6;

    --app-default-attribute-title-color: #797593;
    --app-default-button-text-color: #faf4ed;
    --app-default-text-color: #575279;
    --app-default-alt-text-color: #6e6a86;
    --app-default-link-color: #907aa9;
    --app-default-link-hover-color: #d7827e;

    --app-inverted-text-color: #fffaf3;
    --app-inverted-alt-text-color: #f2e9e1;

    --app-side-navigation-bg-color: #56526e;
    --app-side-navigation-text-color: #faf4ed;
    --app-side-navigation-link-color: #faf4ed;
    --app-side-navigation-link-hover-color: #ebbcba;

    --app-top-navigation-bg-color: #fffaf3;
    --app-top-navigation-text-color: #575279;
    --app-top-navigation-link-color: #907aa9;
    --app-top-navigation-link-hover-color: #d7827e;

    --app-footer-bg-color: #f2e9e1;
    --app-footer-text-color: #575279;
    --app-footer-link-color: #907aa9;
    --app-footer-link-hover-color: #d7827e;

    --app-table-row-color: #faf4ed;
    --app-table-row-alt-color: #f2e9e1;
    --app-table-row-hover-color: #e6ddd6;

    --bs-border-color: #e6ddd6;

    --app-border-translucent-light: rgba(206, 202, 205, 0.175);
    --app-focus-ring-primary: rgba(144, 122, 169, 0.25);
}
