# Generated by Django 5.2.7 on 2025-11-07 23:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_spire_knowledge', '0006_alter_entryversionblock_type'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='collection',
            options={'ordering': ['name'], 'permissions': [('can_access_all_collections', 'Can Access All Collections'), ('can_change_collection_groups', 'Can Change Collection Groups')], 'verbose_name': 'Collection', 'verbose_name_plural': 'Collections'},
        ),
    ]
