# Generated by Django 5.1.8 on 2025-11-13 20:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_spire_file', '0001_initial'),
        ('django_spire_notification_email', '0002_emailnotification_bcc_emailnotification_cc_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailnotification',
            name='attachments',
            field=models.ManyToManyField(blank=True, related_name='attachments', related_query_name='attachment', to='django_spire_file.file'),
        ),
    ]
