# Generated by Django 5.2.7 on 2025-10-22 01:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_spire_knowledge', '0004_alter_collection_options_collectiongroup'),
    ]

    operations = [
        migrations.AddField(
            model_name='entryversionblock',
            name='_tunes_data',
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='entryversionblock',
            name='type',
            field=models.CharField(choices=[('text', 'Text'), ('heading', 'Heading'), ('sub_heading', 'Sub Heading'), ('list_item', 'List Item'), ('list', 'List'), ('code', 'Code')], default='text', max_length=32),
        ),
    ]
