# Generated by Django 5.2.7 on 2025-11-12 16:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_spire_core', '0001_initial'),
        ('django_spire_knowledge', '0007_alter_collection_options'),
    ]

    operations = [
        migrations.AddField(
            model_name='collection',
            name='tags',
            field=models.ManyToManyField(blank=True, editable=False, null=True, related_name='+', to='django_spire_core.tag'),
        ),
        migrations.AddField(
            model_name='entry',
            name='tags',
            field=models.ManyToManyField(blank=True, editable=False, null=True, related_name='+', to='django_spire_core.tag'),
        ),
    ]
